/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
** This file is part of the Qt Quick Controls 2 module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see http://www.qt.io/terms-conditions. For further
** information use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPLv3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or later as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file. Please review the following information to
** ensure the GNU General Public License version 2.0 requirements will be
** met: http://www.gnu.org/licenses/gpl-2.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

import QtQuick 2.12
import QtQuick.Templates 2.12 as T
import QtQuick.Controls 2.12
import QtQuick.Controls.impl 2.12
import org.ukui.qqc2style.private 1.0 as StylePrivate

T.CheckDelegate {
    id: control

    implicitWidth: Math.max(implicitBackgroundWidth + leftInset + rightInset,
                            implicitContentWidth + spacing + leftPadding + rightPadding)
    implicitHeight: Math.max(implicitBackgroundHeight + topInset + bottomInset,
                             implicitContentHeight + topPadding + bottomPadding,
                             implicitIndicatorHeight + topPadding + bottomPadding)

    padding: checkbox.upDownMargin
    spacing: checkbox.space
    leftPadding: checkbox.leftRightMargin

    icon.width: app.iconWidth
    icon.height: app.iconWidth
    icon.color: control.palette.text
    hoverEnabled: true

    property var borderColor: control.checked ? (!control.enabled ? checkbox.checked_disableIndicatorBorderColor :
                                                                    control.pressed ? checkbox.checked_clickIndicatorBorderColor : control.hovered ?
                                                                    checkbox.checked_hoverIndicatorBorderColor : checkbox.checked_normalIndicatorBorderColor) :
                                                                   (!control.enabled ? checkbox.disableIndicatorBorderColor : control.pressed ?
                                                                    checkbox.clickIndicatorBorderColor : control.hovered ?
                                                                    checkbox.hoverIndicatorBorderColor : checkbox.normalIndicatorBorderColor)

    property var checkBoxColor: control.checked ? (!control.enabled ? checkbox.checked_disableIndicatorColor :
                                                                        control.pressed ? checkbox.checked_clickIndicatorColor : control.hovered ?
                                                                        checkbox.checked_hoverIndicatorColor : checkbox.checked_normalIndicatorColor) :
                                                                       (!control.enabled ? checkbox.disableIndicatorColor : control.pressed ?
                                                                        checkbox.clickIndicatorColor : control.hovered ?
                                                                        checkbox.hoverIndicatorColor : checkbox.normalIndicatorColor)
    ParseInterface{
        id: parseInterface
    }

    function getStartColor(dtcolor)
    {
        return parseInterface.pStartColor(dtcolor)
    }
    function getEndColor(dtcolor)
    {
        return parseInterface.pEndColor(dtcolor)
    }
    StylePrivate.APPParameter{
        id: app
        onParametryChanged:{
            control.update();
        }
    }
    StylePrivate.UKUICheckBox{
        id: checkbox
    }

    onWidthChanged: {
        indicator.update()
        contentItem.update()
        control.update()
    }

//    contentItem: IconLabel {
//        leftPadding: control.mirrored ? control.indicator.width + control.spacing : control.leftPadding
//        rightPadding: !control.mirrored ? control.indicator.width + control.spacing : control.rightPadding
//        //x: control.text ? (control.mirrored ? control.leftPadding :control.width - width - control.rightPadding) : control.leftPadding + (control.availableWidth - width) / 2

//        spacing: control.spacing
//        mirrored: control.mirrored
//        display: control.display
//        alignment: control.display === IconLabel.IconOnly || control.display === IconLabel.TextUnderIcon ? Qt.AlignCenter : Qt.AlignLeft

//        icon: control.icon
//        text: control.text
//        font: app.font
//        color: getStartColor(control.enabled ? checkbox.normalTextColor : checkbox.disableTextColor)
//        Rectangle{
//        anchors.fill: parent
//        color: "red"
//        }
//    }

    contentItem: IconLabelContent {
        id: iconLabel
        controlRoot: control
        anchors.left: control.left
        leftSpace: control.mirrored ? control.indicator.width + control.spacing : control.leftPadding
        //x: 0// control.text ? (control.mirrored ? control.leftPadding : control.width - width - control.rightPadding) : control.leftPadding + (control.availableWidth - width) / 2
        //anchors.centerIn: control
        implicitWidth: iconLabel.adjustWidth(control.leftPadding + control.rightPadding) + indicator.implicitWidth + control.spacing
    }

    // keep in sync with CheckDelegate.qml (shared CheckIndicator.qml was removed for performance reasons)
    indicator: Rectangle {
        implicitWidth: checkbox.indicatorWidth
        implicitHeight: checkbox.indicatorWidth

        x: control.mirrored ? control.leftPadding : control.width - width - control.rightPadding
        y: control.topPadding + (control.availableHeight - height) / 2
        radius: checkbox.radius

        border.width: checkbox.borderWidth
        border.color: getStartColor(borderColor)
        color: gradientRec.visible ? "transparent" : getStartColor(checkBoxColor)

        Rectangle{
            id: gradientRec
            anchors.fill: parent
            radius: parent.radius
            border.width: parent.border.width
            border.color: parent.border.color
            gradient:  Gradient {
                id:gradient
                GradientStop { position: 0.0; color: getStartColor(checkBoxColor) }

                GradientStop { position: 1.0; color: getEndColor(checkBoxColor)}
            }
            visible: !parseInterface.isSolidPattern(checkBoxColor)
        }

        Image {
            x: (parent.width - width) / 2
            y: (parent.height - height) / 2
            width: 14
            height: 12
//            defaultColor: "#353637"
//            color: control.palette.text
            source: {
                var model = !control.enabled ? "disenable" : control.checked ? "highlight" : "normal"
                return "image://imageProvider/" + "object-select-symbolic" + "/" + model;
            }
            visible: control.checkState === Qt.Checked
        }

        Rectangle {
            x: (parent.width - width) / 2
            y: (parent.height - height) / 2
            width: 9
            height: 1
            color: {
                getStartColor(!control.enabled ? checkbox.checked_disableChildrenColor :
                                   control.pressed ? checkbox.checked_clickChildrenColor:
                                                     control.hovered ? checkbox.checked_hoverChildrenColor:
                                                                       checkbox.checked_normalChildrenColor)
            }
            visible: control.checkState === Qt.PartiallyChecked
        }
    }
    background: Rectangle {
        implicitWidth: parent.implicitWidth
        implicitHeight: 36
        visible: control.down || control.highlighted
        color: control.down ? control.palette.midlight : control.palette.light
    }
}
